Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIThreadPool.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIThreadPool.cpp	(revision 71525)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIThreadPool.cpp	(revision 71526)
@@ -5,5 +5,5 @@
 
 /*
- * Copyright (C) 2013-2017 Oracle Corporation
+ * Copyright (C) 2013-2018 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
@@ -25,6 +25,6 @@
 /* GUI includes: */
 # include "COMDefs.h"
+# include "UIDefs.h"
 # include "UIThreadPool.h"
-# include "UIDefs.h"
 
 /* Other VBox includes: */
@@ -32,4 +32,5 @@
 
 #endif /* !VBOX_WITH_PRECOMPILED_HEADERS */
+
 
 /** QThread extension used as worker-thread.
@@ -47,5 +48,5 @@
 
     /** Constructs worker-thread for parent worker-thread @a pPool.
-      * @param iIndex defines worker-thread index within the worker-thread pool registry. */
+      * @param  iIndex  Brings worker-thread index within the worker-thread pool registry. */
     UIThreadWorker(UIThreadPool *pPool, int iIndex);
 
@@ -70,4 +71,9 @@
     bool m_fNoFinishedSignal;
 };
+
+
+/*********************************************************************************************************************************
+*   Class UIThreadPool implementation.                                                                                           *
+*********************************************************************************************************************************/
 
 UIThreadPool::UIThreadPool(ulong cMaxWorkers /* = 3 */, ulong cMsWorkerIdleTimeout /* = 5000 */)
@@ -207,5 +213,5 @@
 }
 
-UITask* UIThreadPool::dequeueTask(UIThreadWorker *pWorker)
+UITask *UIThreadPool::dequeueTask(UIThreadWorker *pWorker)
 {
     /* Lock initially: */
@@ -301,4 +307,9 @@
 }
 
+
+/*********************************************************************************************************************************
+*   Class UIThreadWorker implementation.                                                                                         *
+*********************************************************************************************************************************/
+
 UIThreadWorker::UIThreadWorker(UIThreadPool *pPool, int iIndex)
     : m_pPool(pPool)
@@ -332,4 +343,5 @@
 }
 
+
 #include "UIThreadPool.moc"
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIThreadPool.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIThreadPool.h	(revision 71525)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIThreadPool.h	(revision 71526)
@@ -5,5 +5,5 @@
 
 /*
- * Copyright (C) 2013-2017 Oracle Corporation
+ * Copyright (C) 2013-2018 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
@@ -20,6 +20,6 @@
 
 /* Qt includes: */
+#include <QMutex>
 #include <QObject>
-#include <QMutex>
 #include <QQueue>
 #include <QSet>
@@ -29,6 +29,7 @@
 
 /* Forward declarations: */
+class UITask;
 class UIThreadWorker;
-class UITask;
+
 
 /** QObject extension used as worker-thread pool.
@@ -46,7 +47,7 @@
 
     /** Constructs worker-thread pool.
-      * @param cMaxWorkers          defines the maximum amount of worker-threads.
-      * @param cMsWorkerIdleTimeout defines the maximum amount of time (in ms) which
-      *                             pool will wait for the worker-thread on cleanup. */
+      * @param  cMaxWorkers           Brings the maximum amount of worker-threads.
+      * @param  cMsWorkerIdleTimeout  Brings the maximum amount of time (in ms) which
+      *                               pool will wait for the worker-thread on cleanup. */
     UIThreadPool(ulong cMaxWorkers = 3, ulong cMsWorkerIdleTimeout = 5000);
     /** Destructs worker-thread pool. */
@@ -60,7 +61,6 @@
     /** Enqueues @a pTask into the task-queue. */
     void enqueueTask(UITask *pTask);
-    /** Returns dequeued top-most task from the task-queue.
-      * @remarks Called by the @a pWorker passed as a hint. */
-    UITask* dequeueTask(UIThreadWorker *pWorker);
+    /** Returns dequeued top-most task from the task-queue. */
+    UITask *dequeueTask(UIThreadWorker *pWorker);
 
 private slots:
@@ -78,15 +78,15 @@
         /** Holds the maximum amount of time (in ms) which
           * pool will wait for the worker-thread on cleanup. */
-        const ulong m_cMsIdleTimeout;
+        const ulong               m_cMsIdleTimeout;
         /** Holds the vector of worker-threads. */
-        QVector<UIThreadWorker*> m_workers;
+        QVector<UIThreadWorker*>  m_workers;
         /** Holds the number of worker-threads.
           * @remarks We cannot use the vector size since it may contain 0 pointers. */
-        int m_cWorkers;
+        int                       m_cWorkers;
         /** Holds the number of idle worker-threads. */
-        int m_cIdleWorkers;
+        int                       m_cIdleWorkers;
         /** Holds whether the 'termination sequence' is started
           * and all worker-threads should terminate ASAP. */
-        bool m_fTerminating;
+        bool                      m_fTerminating;
     /** @} */
 
@@ -94,7 +94,7 @@
      * @{ */
         /** Holds the queue of pending tasks. */
-        QQueue<UITask*> m_pendingTasks;
+        QQueue<UITask*>  m_pendingTasks;
         /** Holds the set of executing tasks. */
-        QSet<UITask*> m_executingTasks;
+        QSet<UITask*>    m_executingTasks;
         /** Holds the condition variable that gets signalled when
           * queuing a new task and there are idle worker threads around.
@@ -103,5 +103,5 @@
           *          broadcast signal to wake up all workers (after
           *          setting m_fTerminating of course). */
-        QWaitCondition m_taskCondition;
+        QWaitCondition   m_taskCondition;
     /** @} */
 
@@ -110,4 +110,5 @@
     mutable QMutex m_everythingLocker;
 };
+
 
 /** QObject extension used as worker-thread task interface.
@@ -131,9 +132,9 @@
     };
 
-    /** Constructs the task of passed @a type. */
-    UITask(UITask::Type type) : m_type(type) {}
+    /** Constructs the task of passed @a enmType. */
+    UITask(UITask::Type enmType) : m_enmType(enmType) {}
 
     /** Returns the type of the task. */
-    UITask::Type type() const { return m_type; }
+    UITask::Type type() const { return m_enmType; }
 
     /** Starts the task. */
@@ -142,6 +143,5 @@
 protected:
 
-    /** Contains the abstract task body.
-      * @remarks To be reimplemented in sub-class. */
+    /** Contains the abstract task body. */
     virtual void run() = 0;
 
@@ -149,6 +149,7 @@
 
     /** Holds the type of the task. */
-    const UITask::Type m_type;
+    const UITask::Type m_enmType;
 };
+
 
 #endif /* !___UIThreadPool_h___ */
